@@ -10,14 +10,15 @@ from libgsync.output import verbose, debug
 from libgsync.drive.mimetypes import MimeTypes
 from libgsync.drive.file import DriveFile
 
-import gflags
-
 # Set to True for strict positional parameter exceptions in oauth2client
-if False:
-    gflags.FLAGS['positional_parameters_enforcement'].value = 'EXCEPTION'
-else:
-    gflags.FLAGS['positional_parameters_enforcement'].value = 'IGNORE'
-
+try:
+    import gflags
+    if False:
+        gflags.FLAGS['positional_parameters_enforcement'].value = 'EXCEPTION'
+    else:
+        gflags.FLAGS['positional_parameters_enforcement'].value = 'IGNORE'
+except Exception:
+    pass
 
 if debug.enabled():
     import logging
@@ -178,13 +179,14 @@ class _Drive():
         self._service = None
         self._credentialStorage = None
         
-        # Load Google Drive local cache (currently disabled)
-        cfg = self._getConfigFile("drive.v2.gcache")
-        self._gcache = shelve.open(cfg, flag = 'n')
+        # Load Google Drive local cache
+        self._gcache = {}
 
-        # Load parent folder cache (currently disabled)
-        cfg = self._getConfigFile("drive.v2.pcache")
-        self._pcache = shelve.open(cfg, flag = 'n')
+        # Load parent folder cache
+        self._pcache = {}
+
+        # Load file properties cache
+        self._icache = {}
 
         debug("Initialisation complete")
 
@@ -247,12 +249,6 @@ class _Drive():
             if storage is not None:
                 storage.put(credentials)
 
-        debug("Saving gcache (%d items)..." % len(self._gcache))
-        self._gcache.close()
-
-        debug("Saving pcache (%d items)..." % len(self._pcache))
-        self._pcache.close()
-
         debug("My pid = %d" % os.getpid())
 
     def _getConfigDir(self, subdir = None):
@@ -301,23 +297,22 @@ class _Drive():
             raise ENoTTY
 
         # Locate the client.json file.
-        client_json_locations = [
-            '/usr/local/libgsync/data/client.json',
-            '/usr/share/libgsync/data/client.json',
-            '/usr/local/share/libgsync/data/client.json',
-            '/usr/lib/libgsync/data/client.json',
-            '/usr/libgsync/data/client.json',
-            os.path.join(os.path.dirname(__file__), 'data', 'client.json'),
-        ]
-        client_json = None
+        client_json = self._getConfigFile("client.json")
 
-        for f in client_json_locations:
-            if os.path.exists(f):
-                client_json = f
-                break
+        # Create the client.json file if not present.
+        if not os.path.exists(client_json):
+            try:
+                from libgsync.drive.client_json import client_obj
 
-        if client_json is None:
-            raise EFileNotFound('data/client.json')
+                with open(client_json, "w") as f:
+                    f.write(json.dumps(client_obj))
+
+            except Exception, e:
+                debug("Exception: %s" % str(e))
+                raise
+
+        if not os.path.exists(client_json):
+            raise EFileNotFound(client_json)
 
         # Reresh token not available through config, so let's request a new
         # one using the app client ID and secret.  Here, we need to obtain an
@@ -426,6 +421,11 @@ class _Drive():
 
         return None
 
+    # TODO: Implement function for obtaining and caching properties.
+    def _getProperties(self, ent):
+        debug("Fetching file properties: %s" % str(ent))
+        return None
+
     def stat(self, path):
         self.validatepath(path)
         path = self.normpath(path)
@@ -484,6 +484,9 @@ class _Drive():
             if ent is None:
                 return None
 
+            # Obtain file properties.
+            props = self._getProperties(ent)
+
             # Update path cache.
             if self._pcache.get(search) is None:
                 debug("Updating path cache: %s" % search)
@@ -493,10 +496,14 @@ class _Drive():
                 debug("Found %s" % search)
                 debug(" * ent: %s" % ent)
                 df = DriveFile(path = path, **ent)
+
+                if props is not None:
+                    df.setProperties(props)
+
                 debug(" * returning %s" % df)
                 return df
 
-        # Finally, couldn't find anything, raise an error.
+        # Finally, couldn't find anything, raise an error?
         return None
 
     def rm(self, path, recursive=False):
@@ -752,8 +759,6 @@ class _Drive():
         debug("Updating google cache: %s (%d items)" % (parentId, len(ents)))
         self._gcache[parentId] = ents
 
-        debug("My pid = %d" % os.getpid())
-
         return ents
 
 # The fake Drive() constructor and global drive instance.
